"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var JoinType;
(function (JoinType) {
    JoinType[JoinType["LeftJoinAndSelect"] = 0] = "LeftJoinAndSelect";
    JoinType[JoinType["LeftJoin"] = 1] = "LeftJoin";
    JoinType[JoinType["InnerJoin"] = 2] = "InnerJoin";
    JoinType[JoinType["InnerJoinAndSelect"] = 3] = "InnerJoinAndSelect";
})(JoinType = exports.JoinType || (exports.JoinType = {}));
var QueryFilters = /** @class */ (function () {
    function QueryFilters(joinFilters, havingFilters) {
        this.joinFilters = joinFilters;
        this.havingFilters = havingFilters;
    }
    return QueryFilters;
}());
exports.QueryFilters = QueryFilters;
var OrderByAction = /** @class */ (function () {
    function OrderByAction(property, type) {
        this.property = property;
        this.type = type;
    }
    return OrderByAction;
}());
exports.OrderByAction = OrderByAction;
var LimitOffsetAction = /** @class */ (function () {
    function LimitOffsetAction(limit, offset) {
        this.limit = limit;
        this.offset = offset;
    }
    return LimitOffsetAction;
}());
exports.LimitOffsetAction = LimitOffsetAction;
var Parameter = /** @class */ (function () {
    function Parameter(key, value) {
        this.key = key;
        this.value = value;
    }
    return Parameter;
}());
exports.Parameter = Parameter;
var JoinFilter = /** @class */ (function () {
    function JoinFilter(property, alias, condition, parameters, joinType) {
        this.property = property;
        this.alias = alias;
        this.condition = condition;
        this.parameters = parameters;
        this.joinType = joinType;
    }
    return JoinFilter;
}());
exports.JoinFilter = JoinFilter;
var HavingFilter = /** @class */ (function () {
    function HavingFilter(having, parameters, inclusive, select) {
        this.having = having;
        this.parameters = parameters;
        this.inclusive = inclusive ? inclusive : false;
        this.select = select ? select : false;
    }
    return HavingFilter;
}());
exports.HavingFilter = HavingFilter;
var QueryUtils = /** @class */ (function () {
    function QueryUtils() {
    }
    QueryUtils.defineFilters = function (qb, joinFilters, orderByActions, limitOffsetAction, havingFilters) {
        if (joinFilters) {
            for (var _i = 0, joinFilters_1 = joinFilters; _i < joinFilters_1.length; _i++) {
                var filter = joinFilters_1[_i];
                switch (filter.joinType) {
                    case JoinType.InnerJoin:
                        qb.innerJoin(filter.property, filter.alias, filter.condition);
                        break;
                    case JoinType.InnerJoinAndSelect:
                        qb.innerJoinAndSelect(filter.property, filter.alias, filter.condition);
                        break;
                    case JoinType.LeftJoin:
                        qb.leftJoin(filter.property, filter.alias, filter.condition);
                        break;
                    case JoinType.LeftJoinAndSelect:
                        qb.leftJoinAndSelect(filter.property, filter.alias, filter.condition);
                        break;
                    default:
                        break;
                }
                if (filter.parameters) {
                    for (var _a = 0, _b = filter.parameters; _a < _b.length; _a++) {
                        var parameter = _b[_a];
                        qb.setParameter(parameter.key, parameter.value);
                    }
                }
            }
        }
        if (orderByActions) {
            for (var _c = 0, orderByActions_1 = orderByActions; _c < orderByActions_1.length; _c++) {
                var orderByAction = orderByActions_1[_c];
                qb.orderBy(orderByAction.property, orderByAction.type);
            }
        }
        if (limitOffsetAction) {
            if (limitOffsetAction.limit) {
                if (joinFilters) {
                    qb.take(limitOffsetAction.limit);
                }
                else {
                    qb.limit(limitOffsetAction.limit);
                }
            }
            if (limitOffsetAction.offset) {
                if (joinFilters) {
                    qb.skip(limitOffsetAction.offset - 1);
                }
                else {
                    qb.offset(limitOffsetAction.offset);
                }
            }
        }
        var first = true;
        if (havingFilters) {
            for (var _d = 0, havingFilters_1 = havingFilters; _d < havingFilters_1.length; _d++) {
                var have = havingFilters_1[_d];
                if (first) {
                    qb.where(have.having);
                    first = false;
                }
                else if (have.inclusive) {
                    qb.andWhere(have.having);
                }
                else {
                    qb.orWhere(have.having);
                }
                if (have.parameters) {
                    for (var _e = 0, _f = have.parameters; _e < _f.length; _e++) {
                        var parameter = _f[_e];
                        qb.setParameter(parameter.key, parameter.value);
                    }
                }
            }
        }
    };
    return QueryUtils;
}());
exports.QueryUtils = QueryUtils;
//# sourceMappingURL=query.utils.js.map