import { City } from './city.type';
import { Entity, Column, OneToOne, JoinColumn, ManyToOne, OneToMany, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsString, IsDefined, IsOptional, IsNotEmpty } from 'class-validator';
import { User } from './user.type';

export enum ActionType {
  // ALL
  ALL = "ALL",
  // DAIRIES
  EDIT_DAIRIES = "EDIT_DAIRIES",
  EXCLUDE_DAIRIES = "EXCLUDE_DAIRIES",
  EDIT_CONTRACTS = "EDIT_CONTRACTS",
  // CONSULTANT
  EDIT_CONSULTANTS = "EDIT_CONSULTANTS",
  ASSOCIATE_PROPERTIES = "ASSOCIATE_PROPERTIES",
  EXCLUDE_CONSULTANTS = "EXCLUDE_CONSULTANTS",
  // VISITS
  EDIT_VISITS = "EDIT_VISITS",
  EDIT_EXTRA_VISITS = "EDIT_EXTRA_VISITS",
  EXCLUDE_VISITS = "EXCLUDE_VISITS",
  // PROPERTIES / FARMERS
  EDIT_FARMERS = "EDIT_FARMERS",
  EDIT_PROPERTIES = "EDIT_PROPERTIES",
  EDIT_AGREEMENTS = "EDIT_AGREEMENTS",
  EXCLUDE_PROPERTIES = "EXCLUDE_PROPERTIES",
  // ADMIN
  EDIT_ADMS = "EDIT_ADMS",
  EXCLUDE_ADMS = "EXCLUDE_ADMS",
  EDIT_PERMISSIONS = "EDIT_PERMISSIONS",
  EXCLUDE_PERMISSIONS = "EXCLUDE_PERMISSIONS",
  // OTHERS
  VIEW_NOTIFICATIONS = "VIEW_NOTIFICATIONS",
  VIEW_MAPS = "VIEW_MAPS",
  VIEW_DASHBOARDS = "VIEW_DASHBOARDS",
  VIEW_INDICATORS = "VIEW_INDICATORS"
  // ...
}

@Entity()
export class Permission extends BasicREntity {

  @IsString()
  @Column({ nullable: false })
  name: string;

  @IsString()
  @Column({ nullable: false, default: `${ActionType.ALL},${ActionType.EDIT_DAIRIES}` })
  actions: String; // ActionType(s)

  // TODO: we can segment for other properties

  @IsOptional()
  @ManyToMany(type => User, user => user.permissions, { nullable: true })
  users?: User[];
}