import { Address } from './address.type';
import { Visit } from './../visit/visit.type';
import { Entity, Column, OneToMany, OneToOne, JoinColumn, ManyToMany, JoinTable } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNumber, IsNotEmpty, IsOptional, IsArray, IsBoolean } from 'class-validator';
import { Permission } from './permission.type';
import { UserFarmer } from '../visit/userFarmer.type';
import { UserConsultant } from '../visit/userConsultant.type';

@Entity()
export class User extends BasicREntity {

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  name: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  email: string;

  @IsString()
  @IsOptional()
  @Column({ nullable: true })
  linkPhoto?: string;

  @IsString()
  @IsOptional()
  @Column({ nullable: true })
  phones?: string;

  @IsOptional()
  @OneToOne(type => Address, { cascade: true, nullable: true })
  @JoinColumn()
  address?: Address;

  @IsBoolean()
  @IsOptional()
  @Column({ nullable: false, default: false })
  relog: boolean;

  @IsBoolean()
  @IsOptional()
  @Column({ nullable: false, default: true })
  tutorial: boolean;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  password: string;

  @IsOptional()
  @OneToMany(type => UserFarmer, userFarmer => userFarmer.user, { nullable: true })
  userFarmer?: UserFarmer[];

  @IsOptional()
  @OneToMany(type => UserConsultant, userConsultant => userConsultant.user, { nullable: true })
  userConsultant?: UserConsultant[];

  @IsOptional()
  @ManyToMany(type => Permission, permission => permission.users, { nullable: true })
  @JoinTable({ name: 'user_permission' })
  permissions?: Permission[];
}