import { IsDate, IsBoolean, IsNumber, IsNotEmpty } from 'class-validator';
import { Column, Entity, ManyToOne, IsNull, OneToOne, JoinColumn, OneToMany } from 'typeorm';
import { Farm } from '../visit/farm.type';
import { BasicREntity } from '../basicR.type';
import { Loan } from './loan.type';

export enum RevenueCategory {
  OTHER,
  MILK,
  ANIMAL,
  MACHINERY, //Vender e alugar
  MANURE,
  PASTURE,
  LOAN
}

@Entity()
export class Revenue extends BasicREntity {
  
  @IsDate()
  @IsNotEmpty()
  @Column({ nullable: false })
  date: Date;

  @IsNotEmpty()
  @ManyToOne(type => Farm, farm => farm.revenues, { nullable: false })
  farm: Farm;

  @IsBoolean()
  @Column({ nullable: false, default: false })
  sell: boolean;

  @IsBoolean()
  @Column({ nullable: false, default: false })
  rent: boolean;

  @IsNumber()
  @Column({ nullable: false, type: 'int' })
  category: RevenueCategory;

  @IsNotEmpty()
  @OneToMany(type => Loan, loan => loan.revenue, { nullable: false })
  loans: Loan[];
}