import { DairyCompany } from './dairyCompany.type';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToOne, OneToMany, ManyToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsDate, IsNotEmpty, IsArray, IsOptional } from 'class-validator';
import { Farm } from './farm.type'
import { Contract } from './contract.type';
import { Visit } from './visit.type';

export enum TypeAgreement {
  TYPE_1 = 1, // Particular
  TYPE_2 = 2 // Industria de Laticinios
}

@Entity()
export class Agreement extends BasicREntity {
  
  @IsDate()
  @IsNotEmpty()
  @Column({ nullable: false })
  endDate: Date;

  @IsDate()
  @IsNotEmpty()
  @Column({ nullable: false })
  initialDate: Date;
  
  @IsOptional()
  @IsNumber()
  @Column({ nullable: true })
  acquiredMonthlyVisits?: number;

  @IsOptional()
  @ManyToOne(type => DairyCompany, dairyCompany => dairyCompany.agreements, { nullable: true })
  dairyCompany?: DairyCompany;

  @IsNotEmpty()
  @ManyToOne(type => Farm, farm => farm.agreements, { nullable: false })
  farm: Farm;

  @IsOptional()
  @IsArray()
  @OneToMany(type => Visit, visit => visit.agreement, { nullable: true })
  visits?: Visit[];

  @IsOptional()
  @ManyToOne(type => Contract, contract => contract.agreements, { nullable: true })
  contract?: Contract;
}