import { IsBiggerThan } from '../../validators/isBiggerThan.validator';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToOne, OneToMany , ManyToOne} from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsDate, IsNotEmpty, IsArray, IsOptional, ValidateIf, IsString } from 'class-validator';
import { DairyCompany } from './dairyCompany.type'
import { Agreement } from './agreement.type';
import BusinessException from '../../exceptions/business.exception';

export enum TypeContract {
  TYPE_1 = 1, // IN76/77
  TYPE_2 = 2 // Programa Leite mais Saudável
}

export enum DayTime {
  MORNING = 1,
  EVENING = 2,
  NIGHT = 3
}

@Entity()
export class Contract extends BasicREntity {

  @IsNotEmpty()
  @ManyToOne(type => DairyCompany, dairyCompany => dairyCompany.contracts, { nullable: false })
  dairyCompany: DairyCompany;

  @IsOptional()
  @IsDate()
  @IsBiggerThan("initialDate", { message: BusinessException.CONTRACT.DATEBIGGER })
  @Column({ nullable: true })
  endDate?: Date;

  @IsDate()
  @IsNotEmpty()
  @Column({ nullable: false })
  initialDate: Date;

  @IsString()
  @IsOptional()
  @Column({ nullable: true })
  cancelReason?: string;

  @IsNumber()
  @IsOptional()
  @Column({ nullable: false, type: 'int' })
  dayTime?: DayTime;

  @IsNumber()
  @IsNotEmpty()
  @Column({ nullable: false, type: 'int' })
  type: TypeContract;

  @IsNumber()
  @Column({ nullable: true, default: 0 })
  acquiredMonthlyVisits: number;

  @IsOptional()
  @IsArray()
  @OneToMany(type => Agreement, agreement => agreement.contract, { nullable: true })
  agreements?: Agreement[];
}