import { Address } from '../app/address.type';
import { Farm } from './farm.type';
import { Agreement } from './agreement.type';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, ManyToOne, OneToMany, OneToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNumber, IsBoolean, IsNotEmpty, IsArray, IsOptional } from 'class-validator';
import { City } from '../app/city.type';
import { Contract } from './contract.type';

@Entity()
export class DairyCompany extends BasicREntity {

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  name: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  companyName: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  identification: string; //cnpj or cpf

  @IsOptional()
  @IsString()
  @Column({ nullable: true })
  phones?: string;

  @IsOptional()
  @IsString()
  @IsNotEmpty()
  @Column({ nullable: true })
  emails?: string;

  @IsNotEmpty()
  @OneToOne(type => Address, { cascade: true, nullable: false })
  @JoinColumn()
  address: Address;

  @IsNumber()
  @IsNotEmpty()
  @Column({ nullable: false })
  payDay: number;

  @IsOptional()
  @IsArray()
  @OneToMany(type => Farm, farm => farm.dairyCompany, { nullable: true })
  farms?: Farm[];

  @IsOptional()
  @IsArray()
  @OneToMany(type => Contract, contract => contract.dairyCompany, { nullable: true })
  contracts?: Contract[];

  @IsOptional()
  @IsArray()
  @OneToMany(type => Agreement, agreement => agreement.dairyCompany, { nullable: true })
  agreements?: Agreement[];
}