import { Farm } from './farm.type';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToMany, ManyToOne, OneToOne, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsNotEmpty, IsOptional, IsArray, IsString } from 'class-validator';
import { User } from '../app/user.type';
import { Visit } from './visit.type';

export enum ConsultantRole {
    CONSULTANT = 1,
    CONSULTANT_AUX = 2
}

@Entity()
export class UserConsultant extends BasicREntity {

    @IsNotEmpty()
    @ManyToOne(type => User, user => user.userConsultant, { nullable: false })
    user: User;

    @IsNumber()
    @Column({ nullable: false, type: 'int' })
    role: ConsultantRole;

    @IsString()
    @IsOptional()
    @Column({ nullable: true })
    school?: string;

    @IsOptional()
    @ManyToOne(type => UserConsultant, userConsultant => userConsultant.supervisor, { nullable: true })
    supervisor?: UserConsultant;

    @IsOptional()
    @ManyToMany(type => Farm, farm => farm.consultants, { nullable: true })
    farms?: Farm[];
    
    @IsOptional()
    @IsArray()
    @OneToMany(type => Visit, visit => visit.consultant, { nullable: true })
    visits?: Visit[];
}