import { BasicREntity } from '../basicR.type';
import { Entity, Column, ManyToOne, OneToOne, JoinColumn } from 'typeorm';
import { Farm } from '../visit/farm.type';
import { AnimalEvent } from './animalEvent.type';
import { IsString, IsNumber, IsDate, IsBoolean, IsNotEmpty, IsOptional } from 'class-validator';

export enum RaceType {
    HOLSTEIN,
    GIR
}

@Entity()
export class Animal extends BasicREntity {

    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    earring?: string;
    
    @IsOptional()
    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false })
    status: number; //Fazer enum
    
    @IsOptional()
    @IsNotEmpty()
    @IsString()
    @Column({ nullable: false })
    name: string;
    
    @IsOptional()
    @Column({ nullable: true })
    nickname?: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    origin?: string;
    
    @IsOptional()
    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    dateOfBirth: Date;
    
    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false })
    numberOfChildBirths: number; //Número de partos não registrados na aplicação
    
    @Column({ nullable: false, type: 'int' })
    sex: number; //Fazer Enum
    
    // // // NumTetasSaudaveis	int Isso deveria estar em outra tabela para termos dados históricos. Nova tabela deve conter grau da lesão e data

    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    dateOfRemovalOfHorns: Date;
    
    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    dateOfWeaning: Date;
    
    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    dataAptitude: Date;
    
    // // // // DataVacinaBrucelose	datetime colocar isso junto com as outras vacinas
    @IsOptional()
    @Column({ nullable: true })
    dateOfDeath?: Date;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    reasonOfDeath?: string;
    
    // DataTransferencia	datetime   PENSAR ESSE RELACIONAMENTO
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    rfid?: string;
    
    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false })
    class: number; //Fazer enum
    
    @IsNumber()
    @Column({ nullable: false, type: 'int'})
    race: RaceType;
    
    // @IsString()
    // @Column({ nullable: false, type: 'int'})
    // animalId: string;
    
    @IsOptional()
    @OneToOne(type => AnimalEvent, { nullable: true })
    @JoinColumn()
    reproductiveEvent?: AnimalEvent;
    
    @IsOptional()
    @ManyToOne(type => Farm, farm => farm.animals, { nullable: true })
    farm?: Farm;
    
    @IsOptional()
    @OneToOne(type => Animal, { nullable: true })
    @JoinColumn()
    mother?: Animal;
    
    @IsOptional()
    @OneToOne(type => Animal, { nullable: true })
    @JoinColumn()
    biologicalMother?: Animal;
    
    @IsOptional()
    @OneToOne(type => Animal, { nullable: true })
    @JoinColumn()
    biologicalFather?: Animal;
}