import { BasicREntity } from '../basicR.type';
import { Entity, Column, OneToOne, JoinColumn } from 'typeorm';
import { Animal } from './animal.type';
import { IsNumber, IsString, IsNotEmpty, IsOptional } from 'class-validator';

export enum AssociationType {
    HOSTEIN,
    GIR,
    GIROLANDO
}

@Entity()
export class AnimalAssociation extends BasicREntity {
    @IsNumber()
    @Column({ nullable: false, type: 'int' })
    association: AssociationType;

    @IsNotEmpty()
    @OneToOne(type => Animal, { nullable: false })
    @JoinColumn()
    animal: Animal;
    
    @IsNotEmpty()
    @IsString()
    @Column({ nullable: false })
    boton: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    registrationPendency?: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    birthRegistration?: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    originCDN?: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    originCDC?: string;
    
    @IsOptional()
    @IsString()
    @Column({ nullable: true })
    definitiveRegistration?: string;
}