import { BasicREntity } from '../basicR.type';
import { Entity, ManyToOne, Column, OneToOne, JoinColumn } from 'typeorm';
import { Animal } from './animal.type';
import { IsNumber, IsDate, IsBoolean, IsNotEmpty } from 'class-validator';

export enum ReproductiveEvent {
    IMPREGNATION,
    OBSERVED_HEAT,
    FOLICULAR_ASPIRATION,
    EMBRIO_COLLECT,
    EMBRIO_TRANSFER,
    CONVENTIONAL_SEMEN,
    SEXED_SEMEN,
    IN_VITRO_FERTILIZATION,
    REPRODUCTIVE_OCCURENCE,
    EMBRIO_ABSORBTION,
    ABORTION_WITHOUT_LACTATION,
    MALE_BIRTH,
    FEMALE_BIRTH,
    MALE_MALE_BIRTH,
    MALE_FEMALE_BIRTH,
    FEMALE_FEMALE_BIRTH,
    ABORTION_WITH_LACTATION,
    STILLBIRTH,
    POSITIVE_GESTATION_DIAGNOSIS,
    NEGATIVE_GESTATION_DIAGNOSIS,
    BIRTH_NOT_REGISTERED_IN_APP
}

@Entity()
export class AnimalEvent extends BasicREntity {

    @IsNotEmpty()
    @OneToOne(type => Animal, { nullable: false })
    @JoinColumn()
    animal: Animal;

    @IsNumber()
    @Column({ nullable: false, type: 'int' })
    reproductiveEvent: ReproductiveEvent;
    
    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    eventDate: Date;

    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false })
    cicle: number;
    
    @IsBoolean()
    @Column({ nullable: false, default: false })
    cicleClosure: boolean;
}