import {registerDecorator, ValidationOptions, ValidationArguments} from "class-validator";

export function IsBiggerThan(property: string, validationOptions?: ValidationOptions) {
   return function (object: Object, propertyName: string) {
        registerDecorator({
            name: "IsBiggerThan",
            target: object.constructor,
            propertyName: propertyName,
            constraints: [property],
            options: validationOptions,
            validator: {
                validate(value: any, args: ValidationArguments) {
                    const [relatedPropertyName] = args.constraints;
                    let relatedValue = (args.object as any)[relatedPropertyName];
                    if (typeof value === 'string') {
                        value = new Date(value);
                    }

                    if (typeof relatedValue === 'string') {
                        relatedValue = new Date(relatedValue);
                    }
                    
                    return value.getTime() > relatedValue.getTime();
                }
            }
        });
   };
}